@@ -69,10 +69,13 @@ private slots:
     void createWindow(Profile::Ptr profile , const QString& directory);
     void detachView(Session* session);
 
+    void toggleBackgroundInstance();
+
 private:
     void init();
     void listAvailableProfiles();
     void listProfilePropertyInfo();
+    void startBackgroundMode(MainWindow* window);
     bool processHelpArgs(KCmdLineArgs* args);
     MainWindow* processWindowArgs(KCmdLineArgs* args);
     Profile::Ptr processProfileSelectArgs(KCmdLineArgs* args);
@@ -80,6 +83,8 @@ private:
     void processTabsFromFileArgs(KCmdLineArgs* args, MainWindow* window);
     void createTabFromArgs(KCmdLineArgs* args, MainWindow* window,
                            const QHash<QString, QString>&);
+
+    MainWindow* _backgroundInstance;
 };
 }
 #endif  // APPLICATION_H
