@@ -106,6 +106,7 @@ public:
     void setNavigationVisibility(int visibility);
     void setNavigationPosition(int position);
     void setNavigationStyleSheet(const QString& stylesheet);
+    void setNavigationStyleSheetFromFile(const KUrl& stylesheetfile);
     void setNavigationBehavior(int behavior);
     void setShowQuickButtons(bool show);
 
@@ -159,8 +160,6 @@ private slots:
     void profileListChanged(const QList<QAction*>& actions);
     void configureNotifications();
 
-    void setSaveGeometryOnExit(bool visible);
-
     void updateWindowIcon();
     void updateWindowCaption();
 
