@@ -45,14 +45,16 @@
 #include <KUser>
 #include <KDebug>
 
-#if defined(Q_OS_MAC)
+#if defined(Q_OS_FREEBSD) || defined(Q_OS_OPENBSD) || defined(Q_OS_MAC)
 #include <sys/sysctl.h>
+#endif
+
+#if defined(Q_OS_MAC)
 #include <libproc.h>
 #include <kde_file.h>
 #endif
 
 #if defined(Q_OS_FREEBSD) || defined(Q_OS_OPENBSD)
-#include <sys/sysctl.h>
 #include <sys/types.h>
 #include <sys/user.h>
 #include <sys/syslimits.h>
@@ -361,6 +363,7 @@ void NullProcessInfo::readUserName()
 {
 }
 
+#if !defined(Q_OS_WIN)
 UnixProcessInfo::UnixProcessInfo(int aPid, bool enableEnvironmentRead)
     : ProcessInfo(aPid, enableEnvironmentRead)
 {
@@ -411,7 +414,9 @@ void UnixProcessInfo::readUserName()
     }
     delete [] getpwBuffer;
 }
+#endif
 
+#if defined(Q_OS_LINUX)
 class LinuxProcessInfo : public UnixProcessInfo
 {
 public:
@@ -603,7 +608,7 @@ private:
     }
 };
 
-#if defined(Q_OS_FREEBSD)
+#elif defined(Q_OS_FREEBSD)
 class FreeBSDProcessInfo : public UnixProcessInfo
 {
 public:
@@ -632,7 +637,7 @@ private:
             return false;
         }
 
-#if defined(__DragonFly__)
+#if defined(HAVE_OS_DRAGONFLYBSD)
         setName(kInfoProc->kp_comm);
         setPid(kInfoProc->kp_pid);
         setParentPid(kInfoProc->kp_ppid);
@@ -682,7 +687,7 @@ private:
     }
 
     virtual bool readCurrentDir(int aPid) {
-#if defined(__DragonFly__)
+#if defined(HAVE_OS_DRAGONFLYBSD)
         char buf[PATH_MAX];
         int managementInfoBase[4];
         size_t len;
@@ -722,9 +727,8 @@ private:
 #endif
     }
 };
-#endif
 
-#if defined(Q_OS_OPENBSD)
+#elif defined(Q_OS_OPENBSD)
 class OpenBSDProcessInfo : public UnixProcessInfo
 {
 public:
@@ -857,9 +861,8 @@ private:
         return true;
     }
 };
-#endif
 
-#if defined(Q_OS_MAC)
+#elif defined(Q_OS_MAC)
 class MacProcessInfo : public UnixProcessInfo
 {
 public:
@@ -917,6 +920,7 @@ private:
 
                 delete [] kInfoProc;
             }
+            setPid(aPid);
         }
         return true;
     }
@@ -939,9 +943,8 @@ private:
         return false;
     }
 };
-#endif
 
-#if defined(Q_OS_SOLARIS)
+#elif defined(Q_OS_SOLARIS)
 // The procfs structure definition requires off_t to be
 // 32 bits, which only applies if FILE_OFFSET_BITS=32.
 // Futz around here to get it to compile regardless,
@@ -952,21 +955,6 @@ private:
 #undef _FILE_OFFSET_BITS
 #endif
 #include <procfs.h>
-#else
-// On non-Solaris platforms, define a fake psinfo structure
-// so that the SolarisProcessInfo class can be compiled
-//
-// That avoids the trap where you change the API and
-// don't notice it in #ifdeffed platform-specific parts
-// of the code.
-struct psinfo {
-    int pr_ppid;
-    int pr_pgid;
-    char* pr_fname;
-    char* pr_psargs;
-};
-static const int PRARGSZ = 1;
-#endif
 
 class SolarisProcessInfo : public UnixProcessInfo
 {
@@ -1024,6 +1012,7 @@ private:
         }
     }
 };
+#endif
 
 SSHProcessInfo::SSHProcessInfo(const ProcessInfo& process)
     : _process(process)
