@@ -346,6 +346,7 @@ protected:
     virtual void readUserName(void);
 };
 
+#if !defined(Q_OS_WIN)
 /**
  * Implementation of ProcessInfo for Unix platforms which uses
  * the /proc filesystem
@@ -397,6 +398,7 @@ private:
      */
     virtual bool readCurrentDir(int pid) = 0;
 };
+#endif
 
 /**
  * Lightweight class which provides additional information about SSH processes.
