@@ -49,7 +49,7 @@ namespace Konsole
  * To start the terminal process, call the start() method
  * with the program name and appropriate arguments.
  */
-class Pty: public KPtyProcess
+class KONSOLEPRIVATE_EXPORT Pty: public KPtyProcess
 {
     Q_OBJECT
 
@@ -84,13 +84,10 @@ public:
      * @param environment A list of key=value pairs which will be added
      * to the environment for the new process.  At the very least this
      * should include an assignment for the TERM environment variable.
-     * @param addToUtmp Specifies whether a utmp entry should be created for
-     * the pty used.  See K3Process::setUsePty()
      */
     int start(const QString& program,
               const QStringList& arguments,
-              const QStringList& environment,
-              bool addToUtmp
+              const QStringList& environment
              );
 
     /** Control whether the pty device is writeable by group members. */
@@ -107,10 +104,10 @@ public:
     bool flowControlEnabled() const;
 
     /**
-     * Sets the size of the window (in lines and columns of characters)
+     * Sets the size of the window (in columns and lines of characters)
      * used by this teletype.
      */
-    void setWindowSize(int lines, int cols);
+    void setWindowSize(int columns, int lines);
 
     /** Returns the size of the window used by this teletype.  See setWindowSize() */
     QSize windowSize() const;
