@@ -150,6 +150,16 @@ void HTMLDecoder::begin(QTextStream* output)
 
     QString text;
 
+    text.append("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n");
+    text.append("\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n");
+    text.append("<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\" xml:lang=\"en\">\n");
+    text.append("<head>\n");
+    text.append("<title>Konsole output</title>\n");
+    text.append("<meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\" />\n");
+    text.append("</head>\n");
+    text.append("<body>\n");
+    text.append("<div>\n");
+
     //open monospace span
     openSpan(text, "font-family:monospace");
 
@@ -163,6 +173,9 @@ void HTMLDecoder::end()
     QString text;
 
     closeSpan(text);
+    text.append("</div>\n");
+    text.append("</body>\n");
+    text.append("</html>\n");
 
     *_output << text;
 
@@ -184,8 +197,10 @@ void HTMLDecoder::decodeLine(const Character* const characters, int count, LineP
         if (characters[i].rendition != _lastRendition  ||
                 characters[i].foregroundColor != _lastForeColor  ||
                 characters[i].backgroundColor != _lastBackColor) {
-            if (_innerSpanOpen)
+            if (_innerSpanOpen) {
                 closeSpan(text);
+                _innerSpanOpen = false;
+            }
 
             _lastRendition = characters[i].rendition;
             _lastForeColor = characters[i].foregroundColor;
@@ -244,16 +259,20 @@ void HTMLDecoder::decodeLine(const Character* const characters, int count, LineP
                     text.append(ch);
             }
         } else {
-            text.append("&nbsp;"); //HTML truncates multiple spaces, so use a space marker instead
+            // HTML truncates multiple spaces, so use a space marker instead
+            // Use &#160 instead of &nbsp so xmllint will work.
+            text.append("&#160;"); 
         }
     }
 
     //close any remaining open inner spans
-    if (_innerSpanOpen)
+    if (_innerSpanOpen) {
         closeSpan(text);
+        _innerSpanOpen = false;
+    }
 
     //start new line
-    text.append("<br>");
+    text.append("<br />");
 
     *_output << text;
 }
