@@ -20,22 +20,22 @@
 #include "ZModemDialog.h"
 
 // KDE
-#include <KLocale>
+#include <KLocalizedString>
 #include <KTextEdit>
 
-using namespace Konsole;
+using Konsole::ZModemDialog;
 
-ZModemDialog::ZModemDialog(QWidget* parent, bool modal, const QString& caption)
- : KDialog( parent )
+ZModemDialog::ZModemDialog(QWidget* aParent, bool modal, const QString& caption)
+    : KDialog(aParent)
 {
-    setObjectName( QLatin1String( "zmodem_progress" ) );
-    setModal( modal );
-    setCaption( caption );
+    setObjectName(QLatin1String("zmodem_progress"));
+    setModal(modal);
+    setCaption(caption);
 
-    setButtons( KDialog::User1 | KDialog::Close );
-    setButtonGuiItem( KDialog::User1, KGuiItem(i18n("&Stop")) );
-    setDefaultButton( KDialog::Close );
-    setEscapeButton( KDialog::User1 );
+    setButtons(KDialog::User1 | KDialog::Close);
+    setButtonGuiItem(KDialog::User1, KGuiItem(i18n("&Stop")));
+    setDefaultButton(KDialog::Close);
+    setEscapeButton(KDialog::User1);
     enableButton(KDialog::Close, false);
 
     _textEdit = new KTextEdit(this);
@@ -44,15 +44,15 @@ ZModemDialog::ZModemDialog(QWidget* parent, bool modal, const QString& caption)
     setMainWidget(_textEdit);
 
     connect(this, SIGNAL(user1Clicked()), this, SLOT(slotClose()));
-    connect(this,SIGNAL(closeClicked()),this,SLOT(slotClose()));
+    connect(this, SIGNAL(closeClicked()), this, SLOT(slotClose()));
 }
 
 void ZModemDialog::addProgressText(const QString& text)
 {
-    QTextCursor cursor = _textEdit->textCursor();
+    QTextCursor currentCursor = _textEdit->textCursor();
 
-    cursor.insertBlock();
-    cursor.insertText(text);
+    currentCursor.insertBlock();
+    currentCursor.insertText(text);
 }
 
 void ZModemDialog::transferDone()
