@@ -207,7 +207,7 @@ int konsole_wcwidth(quint16 oucs)
              (ucs >= 0xf900 && ucs <= 0xfaff) || /* CJK Compatibility Ideographs */
              (ucs >= 0xfe10 && ucs <= 0xfe19) || /* Vertical forms */
              (ucs >= 0xfe30 && ucs <= 0xfe6f) || /* CJK Compatibility Forms */
-             (ucs >= 0xff00 && ucs <= 0xff5f) || /* Fullwidth Forms */
+             (ucs >= 0xff00 && ucs <= 0xff60) || /* Fullwidth Forms */
              (ucs >= 0xffe0 && ucs <= 0xffe6) ||
              (ucs >= 0x300a && ucs <= 0x300b) || /* Special character 《 and 》(Unicode Standard Annex #11) */
              (ucs >= 0x20000 && ucs <= 0x2fffd) ||
