@@ -36,22 +36,10 @@ class PartTest : public QObject
     Q_OBJECT
 
 private slots:
-    void testShortcutOverride();
     void testFd();
 
-// marked as protected so they are not treated as test cases
-protected slots:
-    void overrideShortcut(QKeyEvent* event, bool& override);
-    void shortcutTriggered();
-
 private:
     KParts::Part* createPart();
-
-    // variables for testShortcutOverride()
-    bool _shortcutTriggered;
-    bool _overrideCalled;
-    bool _override;
-    QEventLoop* _shortcutEventLoop;
 };
 
 }
